% file: cap1.m
% Berechnet die Ladekurve und danach Entladekurve eines Kondensators
%
% t1: Zeit des Ladens
% t2 Gesamtzeit (t2-t1 ist damit die Entladezeit)
% C: Kapazität
% R1: Widerstand bei Ladung
% R2: Widerstand bei Entladung
% U0: Leerlaufspannung der Spannungsquelle
%
% Beispiel
% cap1(1e-3,2e-3,1e-6,1e3,1e3,10)
function [retval] = cap1 (t1,t2,C,R1,R2,U0)
t=linspace(0,t2,1001);
U=zeros(1,length(t));
I=zeros(1,length(t));
ll=find(t<=t1);
U(ll)=U0*(1-exp(-t(ll)./R1./C));
I(ll)=U0/R1*exp(-t(ll)./R1./C);
umax=U(ll(end));
ll=find(t>=t1);
U(ll)=umax*(exp(-(t(ll)-t1)./R2./C));
I(ll)=+umax/R2*(1-exp(-(t(ll)-t1)./R2./C))-umax/R2;
clf;
[ax,h1,h2]=plotyy(t,U,t,I); hold on;
set(h1,'linewidth',4);set(h2,'linewidth',4);
set(h1,'color','b');set(h2,'color','r');
set(ax(2),'ycolor',[1 0 0]);set(ax,'fontsize',16);
xlabel('t/s');ylabel(ax(1),'u/V');ylabel(ax(2),'i/A');
grid on;
endfunction
