%
% Berechnet die Ladekurve einer einfache RC-Kompbination
%
%    +-R--+
%    |    |
%    U    C
%    |    |
%    +----+
%
% R: Widerstand
% C: Kapazität
% U: Quellenspannung
% t: Stopzeit
%
% Ausgabe
% t das Zeitfeld
% uc Spannung über Kapazität
% i Strom
%
% Beispielaufruf
% [t,uc,i]=cap_lade1(1000,1e-6,1,5e-3);

function [t,uc,i] = cap_lade1 (R,C,U,t)
t=linspace(0,t,1001);
% Definition der Spannungsquelle
%uq=@(t) U;
uq=@(t) U*sin(t/(R*C));
uq=@(t) U/2*sign(sin(2*pi*t/(R*C)))+U/2;
uq
% Definition der ODE
ucdot=@(uc,t) (uq(t)-uc)/(R*C);
uc=lsode(ucdot,0,t);
i=(uq(t)-uc')/R;
figure(1); clf; hold on;
[ax,h1,h2]=plotyy(t,uc,t,i); hold on;
set(h1,'linewidth',4);set(h2,'linewidth',4);
set(h1,'color','b');set(h2,'color','r');
set(ax(2),'ycolor',[1 0 0]);set(ax,'fontsize',16);
xlabel('t/s');ylabel(ax(1),'u/V');ylabel(ax(2),'i/A');
grid on;
endfunction
