%
% Berechnet die Ladekurve einer doppelten RC-Kompbination
%
%    +-R1-+--R2--+
%    |    |      |
%    U    C1     C2
%    |    |      |
%    +----+------+
%
% R: Widerstände
% C: Kapazitäten
% U: Quellenspannung
% t: Stopzeit
%
% Ausgabe
% t das Zeitfeld
% uc Spannung über Kapazitäten
% ic Stromstärken
%
% Beispielaufruf
% [t,uc,ic]=cap_lade2([1000 500],[1e-6 5e-6],1,5e-3);

function [t,uc,ic] = cap_lade2 (R,C,U,t)
t=linspace(0,t,1001);
% Definition der Spannungsquelle
uq=@(t) U;
%uq=@(t) U*sin(t/(R(1)*C(1)));
%uq=@(t) U/2*sign(sin(2*pi*t/(R(1)*C(1))))+U/2;
uq
% Definition der ODE
ucdot=@(uc,t) ...
  [uq(t)/(R(1)*C(1))-...
      uc(1)*(1/(R(1)*C(1))+1/(R(2)*C(1)))+uc(2)/(R(2)*C(1));...
    uc(1)/(R(2)*C(2))-uc(2)/(R(2)*C(2))]
uc=lsode(ucdot,[0 0],t);
ic=zeros(length(t),2);
size(uc)
size(ic)
ic(:,1)=(uq(t)'-uc(:,1))'/R(1);
ic(:,2)=(uc(:,1)-uc(:,2))/R(2);
figure(1); clf; hold on;
[ax,h1,h2]=plotyy(t,uc(:,1),t,ic(:,1)); hold on;
set(h1,'linewidth',4);set(h2,'linewidth',4);
set(h1,'color','b');set(h2,'color','r');
set(ax(2),'ycolor',[1 0 0]);set(ax,'fontsize',16);
xlabel('t/s');ylabel(ax(1),'u/V');ylabel(ax(2),'i/A');
grid on;
[ax,h1,h2]=plotyy(t,uc(:,2),t,ic(:,2)); hold on;
set(h1,'linewidth',2);set(h2,'linewidth',2);
set(h1,'color','b');set(h2,'color','r');
endfunction
